package com.fastbee.ggroup.mapper;

import java.util.List;
import com.fastbee.ggroup.domain.GLegend;
import com.github.yulichang.base.MPJBaseMapper;
import org.apache.ibatis.annotations.Mapper;

/**
 * 图例Mapper接口
 *
 * @author kerwincui
 * &#064;date  2024-10-08
 */
@Mapper
public interface GLegendMapper extends MPJBaseMapper<GLegend>
{
    /**
     * 查询图例
     *
     * @param id 图例主键
     * @return 图例
     */
    GLegend selectGLegendById(Long id);

    /**
     * 查询图例列表
     *
     * @param gLegend 图例
     * @return 图例集合
     */
    List<GLegend> selectGLegendList(GLegend gLegend);

    /**
     * 新增图例
     *
     * @param gLegend 图例
     * @return 结果
     */
    int insertGLegend(GLegend gLegend);

    /**
     * 修改图例
     *
     * @param gLegend 图例
     * @return 结果
     */
    int updateGLegend(GLegend gLegend);

    /**
     * 删除图例
     *
     * @param id 图例主键
     * @return 结果
     */
    int deleteGLegendById(Long id);

    /**
     * 批量删除图例
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteGLegendByIds(Long[] ids);
}

